@@ -5,11 +5,11 @@ from collections.__init__ import OrderedDict
 
 
 class FixedSizeDict(OrderedDict):
-    def __init__(self, *args, max=0, **kwargs):
+    def __init__(self, *args, max=0, **kwargs) -> None:
         self._max = max
         super().__init__(*args, **kwargs)
 
-    def __setitem__(self, key, value):
+    def __setitem__(self, key, value) -> None:
         OrderedDict.__setitem__(self, key, value)
         if self._max > 0:
             if len(self) > self._max:
